==> opensearch-dashboards-2.10.0.tgz: opensearch-dashboards/src/plugins/newsfeed/server/config.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.configSchema = void 0;

var _configSchema = require("@osd/config-schema");

var _constants = require("../common/constants");

/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Any modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
const configSchema = _configSchema.schema.object({
  enabled: _configSchema.schema.boolean({
    defaultValue: true
  }),
  service: _configSchema.schema.object({
    pathTemplate: _configSchema.schema.string({
      defaultValue: _constants.NEWSFEED_DEFAULT_SERVICE_PATH
    }),
    urlRoot: _configSchema.schema.conditional(_configSchema.schema.contextRef('prod'), _configSchema.schema.literal(true), // Point to staging if it's not a production release
    _configSchema.schema.string({
      defaultValue: _constants.NEWSFEED_DEFAULT_SERVICE_BASE_URL
    }), _configSchema.schema.string({
      defaultValue: _constants.NEWSFEED_DEV_SERVICE_BASE_URL
    }))
  }),
  defaultLanguage: _configSchema.schema.string({
    defaultValue: _constants.NEWSFEED_FALLBACK_LANGUAGE
  }),
  // TODO: Deprecate since no longer used
  mainInterval: _configSchema.schema.duration({
    defaultValue: '2m'
  }),
  // (2min) How often to retry failed fetches, and/or check if newsfeed items need to be refreshed from remote
  fetchInterval: _configSchema.schema.duration({
    defaultValue: '1d'
  }) // (1day) How often to fetch remote and reset the last fetched time

});

exports.configSchema = configSchema;

==> opensearch-dashboards-3.2.0.tgz: opensearch-dashboards/src/plugins/newsfeed/server/config.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.configSchema = void 0;
var _configSchema = require("@osd/config-schema");
var _constants = require("../common/constants");
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Any modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

const configSchema = exports.configSchema = _configSchema.schema.object({
  enabled: _configSchema.schema.boolean({
    defaultValue: true
  }),
  service: _configSchema.schema.object({
    pathTemplate: _configSchema.schema.string({
      defaultValue: _constants.NEWSFEED_DEFAULT_SERVICE_PATH
    }),
    urlRoot: _configSchema.schema.conditional(_configSchema.schema.contextRef('prod'), _configSchema.schema.literal(true),
    // Point to staging if it's not a production release
    _configSchema.schema.string({
      defaultValue: _constants.NEWSFEED_DEFAULT_SERVICE_BASE_URL
    }), _configSchema.schema.string({
      defaultValue: _constants.NEWSFEED_DEV_SERVICE_BASE_URL
    }))
  }),
  defaultLanguage: _configSchema.schema.string({
    defaultValue: _constants.NEWSFEED_FALLBACK_LANGUAGE
  }),
  // TODO: Deprecate since no longer used
  mainInterval: _configSchema.schema.duration({
    defaultValue: '2m'
  }),
  // (2min) How often to retry failed fetches, and/or check if newsfeed items need to be refreshed from remote
  fetchInterval: _configSchema.schema.duration({
    defaultValue: '1d'
  }) // (1day) How often to fetch remote and reset the last fetched time
});
